@@ -1,11 +1,8 @@
 #-------------------------------------------------------------------------------
-# Lint, run, install an Android App
+# Lint, compile, install, start an Android App using just the command line tools
+# without using ant or gradle, just 100% Pure Perl
 # Philip R Brenan at gmail dot com, Appa Apps Ltd, 2017
-# Make sure that the package name you chose ends with the lowercased
-# name of the folder containing the perl and src folders used by the app
 #-------------------------------------------------------------------------------
-# adb -e shell setprop persist.sys.timezone "Europe/Lisbon"                     # Set time zone on emulator
-# adb -e logcat -d | grep -i "AppaApps" 1> %f && adb -e logcat -c               # Get most recent log entries
 
 package Android::Build;
 require v5.16.0;
@@ -17,7 +14,7 @@ use Data::Table::Text qw(:all);
 use File::Copy;
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 
-our $VERSION = '2017.433';
+our $VERSION = '2017.444';
 
 #-------------------------------------------------------------------------------
 # Constants
@@ -614,12 +611,12 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 =head1 Name
 
-Android::Build - Lint, build, install, run an Android App using just the Android
-command line build tools
+Android::Build - Lint, compile, install, start an Android App using just the
+command line tools without using ant or gradle, just 100% Pure Perl
 
 =head1 Prerequisites
 
- sudo apt-get install imagemagick zip
+ sudo apt-get install imagemagick zip openjdk-8-jdk
  sudo cpan install Data::Table::Text Data::Dump Carp POSIX File::Copy;
 
 And a version of the Android Software Development Kit.
@@ -643,7 +640,8 @@ contains:
  $a->sdk          = qq(~/Android/sdk/);                                         # Android SDK on the local machine
  $a->sdkLevels    = [15,25];                                                    # Min sdk, target sdk for manifest
  $a->androidJar   = $a->sdk."platforms/android-25/android.jar";                 # Android sdk jar
- $a->keyStoreFile = qq(~/keystore/release-key.keystore);                        # Keystore file
+ $a->keyAlias     = qq(xxx);                                                    # Alias of key to be used to sign this app
+ $a->keyStoreFile = qq(~/keystore/release-key.keystore);                        # Key store file
  $a->keyStorePwd  = qq(xxx);                                                    # Password for keystore
 
  $a->build(qw(run));                                                            # Build, install and run the app on the only emulator
@@ -655,6 +653,10 @@ emulator and run:
 
 to compile the sample app and load it into the emulator.
 
+If you do not already have a signing key, you can create one with the supplied script:
+
+ perl SampleApp/perl/generateAKey.pl
+
 =head1 File layout
 
 If your Android build description is in file:
@@ -682,15 +684,110 @@ is your reversed domain name written in lowercase. Executing:
  ...
  $a->build(qw(run));
 
-will copy the files in the b<src> and b<lib> folders into an Android project
-created in the b<tmp> before starting the build of the app.
+will copy the files in the 𝘀𝗿𝗰 and 𝗹𝗶𝗯 folders into an Android project
+created in the app build folder before starting the build of your app.
 
 If this does not meet your requirements, then provide a 𝘀𝘂𝗯
 
-$a->copyFiles = sub ...
+ $a->copyFiles = sub ...
 
-which will be called just before the build begins to allow yopu to copy in any
-other files needed to build the app.
+which will be called just before the build begins to allow you to copy in any
+other files needed to build your app.
+
+=head1 Parameters
+
+You can customize your build by assigning to or reading from the following
+methods:
+
+=head2 activity
+
+Optional: Activity name, default is 'Activity'
+
+=head2 buildTools
+
+REQUIRED: Name of the folder containing the build tools to be used to build the
+app
+
+=head2 buildFolder
+
+Optional: Name of a folder in which to build the app
+
+=head2 copyFiles
+
+Optional: Sub to copy additional files into the app before it is complied
+
+=head2 debug
+
+Optional: Make app debuggable is specified and true
+
+=head2 device
+
+Optional: Device to run on, default is the only emulator
+
+=head2 domain
+
+REQUIRED: Domain name for app
+
+=head2 icon
+
+Optional: Jpg file containing a picture that will be scaled to make
+an icon for the app, default is 'icon.jpg'
+
+=head2 keyAlias
+
+REQUIRED: alias used in keytool to name the key to be used to sign this app
+
+=head2 keyStoreFile
+
+REQUIRED: file name of key store
+
+=head2 keyStorePwd
+
+REQUIRED: password of key store file
+
+=head2 log
+
+Output:   message log
+
+=head2 libs
+
+Optional: extra libraries
+
+=head2 name
+
+Optional: One word name of app, else the name of the folder: '../'
+
+=head2 parameters
+
+Optional: Parameter string to be placed in res for the app
+
+=head2 permissions
+
+Optional: Permissions, a standard useful set is applied
+
+=head2 sdk
+
+REQUIRED: Folder containing Android sdk
+
+=head2 sdkLevels
+
+Optional: [minSdkVersion,targetSdkVersion], default is [15,25]
+
+=head2 src
+
+Optional: Source of app, default is everything in './src' folder
+
+=head2 target
+
+Optional: Number of android sdk to use as found via `android list targets`
+
+=head2 title
+
+Optional: Title of app, default is the name of app
+
+=head2 version
+
+Optional: Version of app, default is today's date
 
 =head1 Installation
 
@@ -709,7 +806,7 @@ http://www.appaapps.com
 
 =head1 Copyright
 
-Copyright (c) 2016 Philip R Brenan.
+Copyright (c) 2017 Philip R Brenan.
 
 This module is free software. It may be used, redistributed and/or
 modified under the same terms as Perl itself.
